===============================
stockbot
===============================

.. image:: https://img.shields.io/travis/ChrisPappalardo/stockbot.svg
        :target: https://travis-ci.org/ChrisPappalardo/stockbot

.. image:: https://img.shields.io/pypi/v/stockbot.svg
        :target: https://pypi.python.org/pypi/stockbot


Stock market analysis library written in Python.

* License: Creative Commons (CC) BY-NC-ND 4.0 https://creativecommons.org/licenses/by-nc-nd/4.0/
* Documentation: https://stockbot.readthedocs.org.

Features
--------

* TODO
